import { expect } from 'chai';
import { ValidationObjectBuilder, ValidationType, validateObject } from '../src/validate';
import * as fs from 'fs';

let build = () => {
    let builder = ValidationObjectBuilder.Create();
    return builder
        .add("Names", true, ValidationType.string, true)
        .add("undefined", true, ValidationType.undefined)
        .add("null", true, ValidationType.null)
        .add("nullOrUndefined", true, ValidationType.nullOrUndefined, true)
        .add("app", true)
        
        .addValidation()
        .add("Name", true, ValidationType.string)
        
        .add("version", true)
        .addValidation()
        .add("major", true, ValidationType.number)
        .add("minor", false, ValidationType.number)
        .endValidation()

        .endValidation()

        .build();
}

describe('Validation object create', () => {
    it('should not throw', () => {
        expect(build).to.not.throw();
    });
});

describe('Validation test', () => {
    let val = build();
    let compare = {
        app: {
            Name: "Test",
            version: {
                major: 2
            }
        },
        Names: [
            "matt",
            "b"
        ],
        null: null as any,
        undefined: undefined as any,
        nullOrUndefined: [null as any, undefined as any]
    }

    let results = validateObject(val, compare);    
    let json = JSON.stringify(results, null, 2);
    fs.writeFile("tests/out/results.json", json, () => {});

    it('should validate without optional', () => expect(results.valid).to.be.true);

    compare.app.version = {...compare.app.version, ...{minor: 2}};
    results = validateObject(val, compare);
    it('should validate with', () => expect(results.valid).to.be.true);
});